SUBROUTINE GPGEO(KPROMA,KSTART,KPROF,KFLEV,PHI,PHIF,PT,PR,PLNPR,PALPH)

!**** *GPGEO* - Computes half and full level geopotential height "gz".

!     Purpose.
!     --------

!      Computes half and full level geopotential height "gz".

!      Laplace relation writes:

!       d (gz)/d prehyd = - RT/pre = - (RT/prehyd) * (prehyd/pre)

!      where:
!       - "gz" is the geopotential height.
!       - "prehyd" is the hydrostatic pressure.
!       - "pre" is the total pressure including non-hydrostatic effects.
!       - "R" is the air constant (including moisture effects).
!       - "T" is the temperature.

!      It is important to note that when relaxing the thin layer hypothesis
!      the geopotential height "gz" is different from the total geopotential
!      "Phi" (used in the RHS of the horizontal wind equation), except
!      at the surface where Phi_s can still be defined by Phi_s = g z[surf].

!      Integrating the Laplace equations yields the following discretisation
!      for "gz".

!      * "gz" at interlayer "lbar":

!        g z[lbar] = g z[surf]
!        + sum[k=L to l+1] (prehyd/pre)[k] R[k] T[k] delta[k]

!      * "gz" at layer "l":

!        g z[l] = g z[lbar] + (prehyd/pre)[l] R[l] T[l] alpha[l]

!**   Interface.
!     ----------
!        *CALL* *GPGEO(...)

!        Explicit arguments :
!        --------------------
!          KPROMA : horizontal dimensioning                          (input)
!          KSTART : start of work                                    (input)
!          KPROF  : depth of work                                    (input)
!          KFLEV  : number of levels                                 (input)
!          PHI    : geopotential height "gz" at interlayers          (output)
!          PHIF   : geopotential height "gz" at layers               (output)
!          PT     : temperature at layers                            (input)
!          PR     : "R" at layers for hydrostatic model              (input)
!                    "(prehyd/pre) R" at layers for NH model
!          PLNPR  : term "delta" on layers                           (input)
!                   (= logarithm of ratio of pressure if "ndlnpr=0")
!          PALPH  : term "alpha" on layers                           (input)

!        Implicit arguments :    None.
!        --------------------

!     Method.
!     -------
!        See documentation

!     Externals.   None.
!     ----------

!     Reference.
!     ----------
!        ECMWF Research Department documentation of the IFS

!     Author.
!     -------
!        Mats Hamrud and Philippe Courtier  *ECMWF*

!     Modifications.
!     --------------
!        Original : 88-02-04
!        K. YESSAD (AUGUST 2000):
!         - correct false comments (especially for NH model and option ndlnpr=1)
!         - relaxation of thin layer hypothesis: no active code changed but
!           correct ambiguous comments and terminology (replace "geopotential"
!           by "geopotential height").
!        01-Oct-2003 M. Hamrud   CY28 Cleaning.
!        02-Jan-2006 J. Masek    Adapted for use with flux.
!     ------------------------------------------------------------------

IMPLICIT NONE

INTEGER,INTENT(IN)    :: KPROMA 
INTEGER,INTENT(IN)    :: KFLEV 
INTEGER,INTENT(IN)    :: KSTART 
INTEGER,INTENT(IN)    :: KPROF 
REAL   ,INTENT(INOUT) :: PHI(KPROMA,0:KFLEV) 
REAL   ,INTENT(OUT)   :: PHIF(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PT(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PR(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PLNPR(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PALPH(KPROMA,KFLEV) 

INTEGER :: JLEV, JLON

!     ------------------------------------------------------------------

!*       1.    COMPUTES HALF AND FULL LEVEL GEOPOTENTIAL HEIGHT.
!              -------------------------------------------------

DO JLEV=KFLEV,1,-1
  DO JLON=KSTART,KPROF
    PHI(JLON,JLEV-1)=PHI(JLON,JLEV)&
     & +PR(JLON,JLEV)*PT(JLON,JLEV)*PLNPR(JLON,JLEV)  

    PHIF(JLON,JLEV) =PHI(JLON,JLEV)&
     & +PALPH(JLON,JLEV)*PR(JLON,JLEV)*PT(JLON,JLEV)  
  ENDDO
ENDDO

!     ------------------------------------------------------------------

END SUBROUTINE GPGEO

