SUBROUTINE GPRCP(KPROMA,KSTART,KPROF,KFLEV,PQ,PQI,PQL,PQR,PQS,PQG,PCP,PR,PKAP)

!**** *GPRCP* - Computes Cp, R and R/Cp from Q

!     Purpose.
!     --------
!           COMPUTES CP AND R  AND R/CP FROM Q

!**   Interface.
!     ----------
!        *CALL* *GPRCP(...)

!        Explicit arguments :
!        --------------------

!        INPUT:
!          KPROMA               - dimensioning.
!          KSTART               - start of work.
!          KPROF                - depth of work.
!          KFLEV                - number of layers.
!          PQ(KPROMA,KFLEV)     - specific humidity.
!          PQI(KPROMA,KFLEV)    - ice.
!          PQL(KPROMA,KFLEV)    - liquid water.
!          PQR(KPROMA,KFLEV)    - rain.
!          PQS(KPROMA,KFLEV)    - snow.
!          PQG(KPROMA,KFLEV)    - graupel.

!        OUTPUT:
!          PCP(KPROMA,KFLEV)    - CP
!          PR(KPROMA,KFLEV)     - R
!          PKAP(KPROMA,KFLEV)   - KAPPA

!        Implicit arguments :  Physical constants from YOMCST
!        --------------------

!     Method.
!     -------
!        See documentation

!     Externals.  None.
!     ----------

!     Reference.
!     ----------
!        ECMWF Research Department documentation of the IFS

!     Author.
!     -------
!        Mats Hamrud and Philippe Courtier  *ECMWF*

!     Modifications.
!     --------------
!        Original : 88-02-04
!        Modified by E.Bazile 94-05-13 (Liquid Water and Ice)
!        01-Oct-2003 M. Hamrud   CY28 Cleaning.
!        13-Feb-2004 Y. Seity    Rain, Snow and Graupel.
!        02-Jan-2006 J. Masek    Adapted for use with flux.
!     ------------------------------------------------------------------

USE MOD_AUX, ONLY: RCPD, RCPV, RCS, RCW, RD, RV,  &
  &  YG, YI, YL, YR, YS

!     ------------------------------------------------------------------

IMPLICIT NONE

INTEGER,INTENT(IN)    :: KPROMA 
INTEGER,INTENT(IN)    :: KFLEV 
INTEGER,INTENT(IN)    :: KSTART 
INTEGER,INTENT(IN)    :: KPROF 
REAL   ,INTENT(IN)    :: PQ(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PQI(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PQL(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PQR(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PQS(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PQG(KPROMA,KFLEV) 
REAL   ,INTENT(OUT)   :: PCP(KPROMA,KFLEV) 
REAL   ,INTENT(OUT)   :: PR(KPROMA,KFLEV) 
REAL   ,INTENT(OUT)   :: PKAP(KPROMA,KFLEV) 

!     ------------------------------------------------------------------

INTEGER :: JLEV, JLON

!     ------------------------------------------------------------------

!*       1.    COMPUTES R AND CP AND KAPPA.
!              ----------------------------

DO JLEV=1,KFLEV
  IF (YL%LACTIVE.AND.YI%LACTIVE.AND.YR%LACTIVE.AND.YS%LACTIVE.AND.YG%LACTIVE) &
   & THEN
    DO JLON=KSTART,KPROF
      PR(JLON,JLEV) =RD*(1.0-PQ(JLON,JLEV)-PQL(JLON,JLEV)-PQI(JLON,JLEV)&
       & -PQR(JLON,JLEV)-PQS(JLON,JLEV)-PQG(JLON,JLEV))&
       & +RV*PQ(JLON,JLEV)  
      PCP(JLON,JLEV)=RCPD*(1.0-PQ(JLON,JLEV)-PQL(JLON,JLEV)-PQI(JLON,JLEV)&
       & -PQR(JLON,JLEV)-PQS(JLON,JLEV)-PQG(JLON,JLEV))&
       & +RCPV*PQ(JLON,JLEV) &
       & +RCW*(PQL(JLON,JLEV)+PQR(JLON,JLEV)) &
       & +RCS*(PQI(JLON,JLEV)+PQS(JLON,JLEV)+PQG(JLON,JLEV))  
      PKAP(JLON,JLEV)=PR(JLON,JLEV)/PCP(JLON,JLEV)
    ENDDO
  ELSEIF (YL%LACTIVE.AND.YI%LACTIVE) THEN
    DO JLON=KSTART,KPROF
      PR(JLON,JLEV) =RD*(1.0-PQ(JLON,JLEV)-PQL(JLON,JLEV)-PQI(JLON,JLEV))&
       & +RV*PQ(JLON,JLEV)  
      PCP(JLON,JLEV)=&
       & RCPD*(1.0-PQ(JLON,JLEV)-PQL(JLON,JLEV)-PQI(JLON,JLEV))&
       & +RCPV*PQ(JLON,JLEV) + RCW*PQL(JLON,JLEV) &
       & +RCS*PQI(JLON,JLEV)  
      PKAP(JLON,JLEV)=PR(JLON,JLEV)/PCP(JLON,JLEV)
    ENDDO
  ELSEIF(YL%LACTIVE) THEN
    DO JLON=KSTART,KPROF
      PR(JLON,JLEV) =RD*(1.0-PQ(JLON,JLEV)-PQL(JLON,JLEV))&
       & +RV*PQ(JLON,JLEV)  
      PCP(JLON,JLEV)=RCPD*(1.0-PQ(JLON,JLEV)-PQL(JLON,JLEV))&
       & +RCPV*PQ(JLON,JLEV) + RCW*PQL(JLON,JLEV)  
      PKAP(JLON,JLEV)=PR(JLON,JLEV)/PCP(JLON,JLEV)
    ENDDO
  ELSEIF(YI%LACTIVE) THEN
    DO JLON=KSTART,KPROF
      PR(JLON,JLEV) =RD*(1.0-PQ(JLON,JLEV)-PQI(JLON,JLEV))&
       & + RV*PQ(JLON,JLEV)  
      PCP(JLON,JLEV)=RCPD*(1.0-PQ(JLON,JLEV)-PQI(JLON,JLEV)) &
       & +RCPV*PQ(JLON,JLEV) + RCS*PQI(JLON,JLEV)  
      PKAP(JLON,JLEV)=PR(JLON,JLEV)/PCP(JLON,JLEV)
    ENDDO
  ELSE
    DO JLON=KSTART,KPROF
      PR(JLON,JLEV) =  RD*(1.0-PQ(JLON,JLEV))+ RV*PQ(JLON,JLEV)
      PCP(JLON,JLEV)=RCPD*(1.0-PQ(JLON,JLEV))+RCPV*PQ(JLON,JLEV)
      PKAP(JLON,JLEV)=PR(JLON,JLEV)/PCP(JLON,JLEV)
    ENDDO
  ENDIF
ENDDO

!     ------------------------------------------------------------------

END SUBROUTINE GPRCP
