SUBROUTINE GPVERDIA(&
 ! ----- INPUT ---------------------------------------------------------------
 & KPROMA,KSTART,KPROF,&
 & PUF,PVF,PDIV,PVVEL,PGPHL,PGPHM,&
 & PLNPR,PALPH,PRT,PKAP,&
 ! ----- OUTPUT --------------------------------------------------------------
 & PDVERV)

USE MOD_AUX, ONLY: NFLEVG

!**** *GPVERDIA* - vertical divergence diagnostics in hydrostatic dynamics

!     Purpose.
!     --------
!      This routine computes the virtual vertical divergence "dverv"
!       dverv = (Rd/R) dver
!      where "dver" is the vertical divergence, in an hydrostatic model.
!      In an hydrostatic model:
!       dverv = -D -X +D3hyd
!       and
!       D3hyd=-(cv/cp)(omega/prehyd)

!      Currently not properly coded for the finite element vertical
!       discretization (LVERTFE=T).

!**   Interface.
!     ----------
!        *CALL* *GPVERDIA(...)

!        Explicit arguments :
!        --------------------

!        * INPUT:
!          KPROMA   : Horizontal dimension.
!          KSTART   : Start of work.
!          KPROF    : End of work.
!          PUF      : U-wind at full levels.
!          PVF      : V-wind at full levels.
!          PDIV     : Divergence at full levels.
!          PVVEL    : (omega/prehyd) at full levels.
!          PGPHL    : zonal component of grad(gz) at half levels.
!          PGPHM    : merid component of grad(gz) at half levels.
!          PLNPR    : "delta" at full levels.
!          PALPH    : "alpha" at full levels.
!          PRT      : R*T at full levels.
!          PKAP     : kappa=R/cp at full levels.

!        * OUTPUT:
!          PDVERV   : virtual vertical divergence "dverv" at full levels.

!        Implicit arguments : none.
!        --------------------

!     Method.
!     -------
!        See documentation

!     Externals.
!     ----------
!     Reference.
!     ----------
!        ARPEGE/ALADIN documentation

!     Author.
!     -------
!        Radmila Bubnova *GMAP/COMPAS - stage MRE*

! Modifications
! -------------
!   Original : 94-01-28
!   Modified:  97-06-24 J.Boutahar (FULL-POS NH)
!   Modified:  98-12-04 L. Gerard: unused args for GPHLUV
!        requires to check LVSLWBC
!   01-Oct-2003 M. Hamrud   CY28 Cleaning.
!   12-Dec-2003 R. Zaaboul  CY28 phasing to call GPHLUV.
!   09-Jun-2004 J. Masek    NH cleaning (LVSLWBC).
!   24-Jan-2005 K. Yessad   Renaming EVERDIA into GPVERDIA; cleanings.
!   02-Jan-2006 J. Masek    Adapted for use with flux.
! End Modifications
!------------------------------------------------------------------

IMPLICIT NONE

INTEGER,INTENT(IN)    :: KPROMA
INTEGER,INTENT(IN)    :: KSTART
INTEGER,INTENT(IN)    :: KPROF
REAL   ,INTENT(IN)    :: PUF(KPROMA,NFLEVG)
REAL   ,INTENT(IN)    :: PVF(KPROMA,NFLEVG)
REAL   ,INTENT(IN)    :: PDIV(KPROMA,NFLEVG)
REAL   ,INTENT(IN)    :: PVVEL(KPROMA,NFLEVG)
REAL   ,INTENT(IN)    :: PGPHL(KPROMA,0:NFLEVG)
REAL   ,INTENT(IN)    :: PGPHM(KPROMA,0:NFLEVG)
REAL   ,INTENT(IN)    :: PLNPR(KPROMA,NFLEVG)
REAL   ,INTENT(IN)    :: PALPH(KPROMA,NFLEVG)
REAL   ,INTENT(IN)    :: PRT(KPROMA,NFLEVG)
REAL   ,INTENT(IN)    :: PKAP(KPROMA,NFLEVG)
REAL   ,INTENT(OUT)   :: PDVERV(KPROMA,NFLEVG)

!     ------------------------------------------------------------------

REAL :: ZX(KPROMA,NFLEVG)
REAL :: ZD3HYD(KPROMA,NFLEVG)
REAL :: ZLHU(KPROMA,0:NFLEVG),ZLHV(KPROMA,0:NFLEVG)
REAL :: ZWWW(KPROMA,NFLEVG)
REAL :: ZUNITE(KPROMA,NFLEVG)

INTEGER :: JLEV, JROF

!     ------------------------------------------------------------------

!*       1.    Computes the horizontal wind at half levels.

CALL GPHLWI(KPROMA,KSTART,KPROF,PLNPR,PALPH,ZWWW,'GPHLWI')
CALL GPHLUV(KPROMA,KSTART,KPROF,ZWWW,PUF,PVF,ZLHU,ZLHV,'GPHLUV')  

!*       2.    X - Term

ZUNITE(KSTART:KPROF,1:NFLEVG)=1.0
CALL GPXX( &
 ! --- INPUT -------------------------------------------------------------
 & NFLEVG,KPROMA,KSTART,KPROF,PGPHL,PGPHM, &
 & PLNPR,ZUNITE,ZUNITE,PRT, &
 & PUF,PVF,ZLHU,ZLHV, &
 ! --- OUTPUT ------------------------------------------------------------
 & ZX &
 & )

!*       3.    Computes D3hyd=-(cv/cp)(omega/prehyd)=(kappa-1)(omega/prehyd)

DO JLEV=1,NFLEVG
  DO JROF=KSTART,KPROF
    ZD3HYD(JROF,JLEV)=(PKAP(JROF,JLEV)-1.0)*PVVEL(JROF,JLEV)
  ENDDO
ENDDO

!*       4.    Computes "dverv" and "dver".

DO JLEV=1,NFLEVG
  DO JROF=KSTART,KPROF
    PDVERV(JROF,JLEV)=-PDIV(JROF,JLEV)-ZX(JROF,JLEV)+ZD3HYD(JROF,JLEV)
  ENDDO
ENDDO

!     ------------------------------------------------------------------

END SUBROUTINE GPVERDIA
