SUBROUTINE GPXX( &
 ! --- INPUT -----------------------------------------------------------------
 & KFLEV,KPROMA,KSTART,KEND,PHIHL,PHIHM, &
 & PLNPR,PNHPPI,PT,PR, &
 & PUF,PVF,PUH,PVH, &
 ! --- OUTPUT ----------------------------------------------------------------
 & PX &
 & )

! GPXX - Diagnose X-term

! Purpose
! -------
!   Diagnose X-term 
!    X = (pre/(RT)) grad[gz] (d V / d prehyd)
!   It is better to rewrite X as follows for the discretisation:
!    X = (pre/prehyd) (1/(RT)) grad[gz] ( d V / d (log(prehyd)) )

!   X is discretised as follows, on layers:
!   [X]_[l] = [pre/prehyd]_[l] * [ 1/(R_[l] T_[l] delta_[l]) ] *
!             [ grad[gz]_[lbar-1] (V_[l] - V[lbar-1])
!             + grad[gz]_[lbar] (V_[lbar] - V_[l]) ]

!   This routine can also be used in a hydrostatic model: in this case
!   the ratio (pre/prehyd) is equal to 1.

! Interface
! ---------
!   * INPUT:
!   KFLEV   - number of levels.
!   KPROMA  - length of work
!   KSTART  - start of work
!   KEND    - end of work
!   PHIHL   - zonal component of "grad[gz]" on half levels.
!   PHIHM   - meridian component of "grad[gz]" on half levels.
!   PLNPR   - "delta" at full levels.
!   PNHPPI  - [pre/prehyd] at full levels.
!   PT      - Temperature at full levels.
!   PR      - R at full levels.
!   PUF     - U-wind at full levels.
!   PVF     - V-wind at full levels.
!   PUH     - U-wind at half levels.
!   PVH     - V-wind at half levels.

!   * OUTPUT:
!   PX      - X-term at full levels.

! Externals
! ---------

! Method
! ------

! Reference
! ---------

! Author
! ------
!   06 Dec 2004 K. Yessad (after GNHX).

! Modifications
! -------------
!   02-Jan-2006 J. Masek    Adapted for use with flux.
! End Modifications
!---------------------------------------------------------------------

! -----------------------------------------------------------------------------

IMPLICIT NONE

INTEGER,INTENT(IN)    :: KFLEV
INTEGER,INTENT(IN)    :: KPROMA 
INTEGER,INTENT(IN)    :: KSTART 
INTEGER,INTENT(IN)    :: KEND 
REAL   ,INTENT(IN)    :: PHIHL(KPROMA,0:KFLEV) 
REAL   ,INTENT(IN)    :: PHIHM(KPROMA,0:KFLEV) 
REAL   ,INTENT(IN)    :: PLNPR(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PNHPPI(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PT(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PR(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PUF(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PVF(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PUH(KPROMA,0:KFLEV) 
REAL   ,INTENT(IN)    :: PVH(KPROMA,0:KFLEV) 
REAL   ,INTENT(OUT)   :: PX(KPROMA,KFLEV) 

! -----------------------------------------------------------------------------

INTEGER :: JLEV, JROF

! -----------------------------------------------------------------------------

DO JLEV=1,KFLEV
  DO JROF=KSTART,KEND
    PX(JROF,JLEV)=( &
     & (PUH(JROF,JLEV)-PUF(JROF,JLEV))*PHIHL(JROF,JLEV) + &
     & (PVH(JROF,JLEV)-PVF(JROF,JLEV))*PHIHM(JROF,JLEV) + &
     & (PUF(JROF,JLEV)-PUH(JROF,JLEV-1))*PHIHL(JROF,JLEV-1) + &
     & (PVF(JROF,JLEV)-PVH(JROF,JLEV-1))*PHIHM(JROF,JLEV-1) &
     & )*PNHPPI(JROF,JLEV)/(PT(JROF,JLEV)*PR(JROF,JLEV)*PLNPR(JROF,JLEV))
  ENDDO
ENDDO

! -----------------------------------------------------------------------------

END SUBROUTINE GPXX

